/* This file is generated by glib-genmarshal, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */
#ifndef __GPM_MARSHAL_MARSHAL_H__
#define __GPM_MARSHAL_MARSHAL_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:INT,BOXED (gpm-marshal.list:1) */
extern
void gpm_marshal_VOID__INT_BOXED (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);

/* VOID:STRING,STRING (gpm-marshal.list:2) */
extern
void gpm_marshal_VOID__STRING_STRING (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:POINTER,STRING,STRING (gpm-marshal.list:3) */
extern
void gpm_marshal_VOID__POINTER_STRING_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:UINT,UINT,BOOLEAN (gpm-marshal.list:4) */
extern
void gpm_marshal_VOID__UINT_UINT_BOOLEAN (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:STRING,STRING,STRING (gpm-marshal.list:5) */
extern
void gpm_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:STRING,BOOLEAN (gpm-marshal.list:6) */
extern
void gpm_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:STRING,STRING,BOOLEAN (gpm-marshal.list:7) */
extern
void gpm_marshal_VOID__STRING_STRING_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:STRING,STRING,BOOLEAN,BOOLEAN,BOOLEAN (gpm-marshal.list:8) */
extern
void gpm_marshal_VOID__STRING_STRING_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* VOID:INT (gpm-marshal.list:9) */
#define gpm_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:STRING (gpm-marshal.list:10) */
#define gpm_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:INT,LONG,BOOLEAN,BOOLEAN (gpm-marshal.list:11) */
extern
void gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN (gpm-marshal.list:12) */
extern
void gpm_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:UINT (gpm-marshal.list:13) */
#define gpm_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT

/* VOID:UINT,UINT (gpm-marshal.list:14) */
extern
void gpm_marshal_VOID__UINT_UINT (GClosure     *closure,
                                  GValue       *return_value,
                                  guint         n_param_values,
                                  const GValue *param_values,
                                  gpointer      invocation_hint,
                                  gpointer      marshal_data);

/* VOID:UINT,POINTER (gpm-marshal.list:15) */
#define gpm_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER


G_END_DECLS

#endif /* __GPM_MARSHAL_MARSHAL_H__ */
